Welcome to Sciris's documentation!
===================================

.. toctree::
    :maxdepth: 1

    general/index
    code_documentation


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
